﻿using System;
using System.Collections.Generic;
using System.Diagnostics.Contracts;
using System.IO;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Threading.Tasks;

namespace animal_wordle
{
    internal class Program
    {
        static List<string> _animals = new List<string> { "duck", "goat", "bear", "lion", "frog", "deer", "swan", "wolf", "crab" }; // create list with all animal names
        /// <summary>
        /// Main method, this handles the intro to the game and calls the Game() method to handle the logic
        /// </summary>
        /// <param name="args"></param>
        static void Main(string[] args)
        {
            string playerName;


            // Get userName
            Console.WriteLine("Welcome to Animal Wordle!");
            Console.Write("What is your name? ");
            playerName = Console.ReadLine();

            //Ask if the user wishes to play
            Console.WriteLine($" Hi {playerName}, do you wish to play? [Y/N]");
            ConsoleKeyInfo cki = Console.ReadKey();

            // check if the user selects yes or no
            if (cki.Key.ToString() == "y" || cki.Key.ToString() == "Y")
            {
                Game();
            }
            else if (cki.Key.ToString() == "n" || cki.Key.ToString() == "N")
            {
                Console.WriteLine("\nYou have chosen not to play :(");
                EndGame();
            }
            else
            {
                EndGame();
            }
        }
        /// <summary>
        /// This method will handle most of the logic for the game
        /// </summary>
        public static void Game()
        {
            Name();

            Console.WriteLine("\nIn Animal Wordle, you have 6 Lives. All of the animals are 4-letter words. If you get a letter in the correct spot, a hash (#) will show.\n If the character is correct but in the wrong position, a hyphen (-) will be shown. And if the letter is no in the animals name, a full-stop (.) will be shown.");

            GuessWord();

            EndGame();
        }

        /// <summary>
        /// This method will randomly select a position within the list and 
        /// set animalName to whichevers name is on that position
        /// </summary>
        public static string Name()
        {
            string animalName;
            Random rnd = new Random();
            int r = rnd.Next(_animals.Count);
            animalName = _animals[r];
            return animalName;
        }

        /// <summary>
        /// This method is in charge of all the logic to do with the player guessing the animals name
        /// and checking to see if the letters are correct or not
        /// </summary>
        public static void GuessWord()
        {
            string selectedAnimal = Name();   // access the selected animal

            // player letter guesses
            string letter1;
            string letter2;
            string letter3;
            string letter4;

            // correct animal letters
            char animalLetter1 = selectedAnimal[0];
            char animalLetter2 = selectedAnimal[1];
            char animalLetter3 = selectedAnimal[2];
            char animalLetter4 = selectedAnimal[3];           

            // loop to iterate through depending on the number of lives
            for (int i = 5; i > -1; i--)
            {
                // get the user to input letters
                Console.WriteLine("\nPlease guess the 4-letter animal:\n");
                Console.WriteLine("Letter 1: ");
                letter1 = Console.ReadLine();
                Console.WriteLine("Letter 2: ");
                letter2 = Console.ReadLine();
                Console.WriteLine("Letter 3: ");
                letter3 = Console.ReadLine();
                Console.WriteLine("Letter 4: ");
                letter4 = Console.ReadLine();


                // check each letter against the animal name
                string result1 = "";
                string result2 = "";
                string result3 = "";
                string result4 = "";
                // check for first letter
                if (letter1[0] == animalLetter1)
                {
                    result1 = "#";
                }
                else if (letter1[0] == animalLetter2 || letter1[0] == animalLetter3 || letter1[0] == animalLetter4)
                {
                    result1 = "-";
                }
                else
                {
                    result1 = ".";
                }
                // check for second letter
                if (letter2[0] == animalLetter2)
                {
                    result2 = "#";
                }
                else if (letter2[0] == animalLetter1 || letter2[0] == animalLetter3 || letter2[0] == animalLetter4)
                {
                    result2 = "-";
                }
                else
                {
                    result2 = ".";
                }

                // check for third letter
                if (letter3[0] == animalLetter3)
                {
                    result3 = "#";
                }
                else if (letter3[0] == animalLetter1 || letter3[0] == animalLetter2 || letter3[0] == animalLetter3)
                {
                    result3 = "-";
                }
                else
                {
                    result3 = ".";
                }

                // check for fourth letter
                if (letter4[0] == animalLetter4)
                {
                    result4 = "#";
                }
                else if (letter4[0] == animalLetter1 || letter4[0] == animalLetter2 || letter4[0] == animalLetter3)
                {
                    result4 = "-";
                }
                else
                {
                    result4 = ".";
                }

                string result = $"{result1}{result2}{result3}{result4}";

                Console.WriteLine(result);

                //checks if the player has won (guessed the animal)
                if (result == "####")
                {
                    Console.WriteLine($"Congratulations, you guessed the correct word! {selectedAnimal}");
                    return;
                }
                else
                {
                    Console.WriteLine($"try again!, you have {i} lives remaining");
                }
            }
        }

        /// <summary>
        /// When the game is over / the user selects not to play, the console will close
        /// </summary>
        public static void EndGame()
        {
            // Will close the console, application is finished
            Console.WriteLine("Thank you for playing Animal Wordle. Press Enter to Close....");
            Console.ReadLine();
        }
    }
}
